@@ -33,27 +33,45 @@
  *    -lz -lm -L/usr/local/lib/
  *
  */
-
-#define EXIT_FAILURE 1
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-
-#include <getopt.h>
-
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #else
 # define VERSION 0.2
 #endif
 
+#define EXIT_FAILURE 1
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#ifndef HAVE_WINDOWS
+#include <sys/errno.h>
+#endif
+
+#include <getopt.h>
+
+
 #ifdef OLD_FFMPEG
 #include <avformat.h>
 #else
 #include <libavformat/avformat.h>
+#include <libavcodec/avcodec.h>
+#if LIBAVFORMAT_BUILD >= 3473920
+#include <libavutil/imgutils.h>
+#endif
+#endif
+
+/* ffmpeg backwards compat */
+#ifndef HAVE_WINDOWS /* XXX temp workaround - win32 older ffmpeg */
+#ifndef CODEC_TYPE_VIDEO
+#define CODEC_TYPE_VIDEO AVMEDIA_TYPE_VIDEO
+#endif
+#ifndef CODEC_TYPE_DATA
+#define CODEC_TYPE_DATA AVMEDIA_TYPE_DATA
+#endif
+#ifndef CODEC_TYPE_AUDIO
+#define CODEC_TYPE_AUDIO AVMEDIA_TYPE_AUDIO
+#endif
 #endif
 
 char *program_name;
@@ -133,28 +151,6 @@ static int decode_switches (int argc, char **argv) {
 }
 
 	
-void print_error(const char *filename, int err)
-{
-  switch (err) {
-  case AVERROR_NUMEXPECTED:
-    fprintf(stderr, "%s: Incorrect image filename syntax.\n"
-		"Use '%%d' to specify the image number:\n"
-		"  for img1.jpg, img2.jpg, ..., use 'img%%d.jpg';\n"
-		"  for img001.jpg, img002.jpg, ..., use 'img%%03d.jpg'.\n",
-		filename);
-    break;
-  case AVERROR_INVALIDDATA:
-    fprintf(stderr, "%s: Error while parsing header\n", filename);
-    break;
-  case AVERROR_NOFMT:
-    fprintf(stderr, "%s: Unknown format\n", filename);
-    break;
-  default:
-    fprintf(stderr, "%s: Error while opening file\n", filename);
-    break;
-  }
-}
-
 int main(int argc, char *argv[])
 {
   AVFormatContext *ic;
@@ -178,7 +174,7 @@ int main(int argc, char *argv[])
 
   err = av_open_input_file(&ic, fn, file_iformat, 0, ap);
   if (err < 0) {
-    print_error(fn, err);
+    fprintf(stderr, "%s: Error while opening file\n", fn);
     return 1;
   }
 
@@ -230,7 +226,11 @@ int main(int argc, char *argv[])
 	printf("w:%d ", codec->width);
 	printf("h:%d #", codec->height);
 	if (p) printf("%s,", p->name);
+#if LIBAVFORMAT_BUILD < 3473920
 	printf("%s", avcodec_get_pix_fmt_name(codec->pix_fmt));
+#else
+	printf("%s", av_get_pix_fmt_name(codec->pix_fmt));
+#endif
 	printf("\n");
 	break;
       }
@@ -262,7 +262,11 @@ int main(int argc, char *argv[])
 	printf("%d,", codec->height);
 	printf("%d:%d,", codec->sample_aspect_ratio.num,codec->sample_aspect_ratio.den);
 	if (p) printf("%s,", p->name);
+#if LIBAVFORMAT_BUILD < 3473920
 	printf("%s", avcodec_get_pix_fmt_name(codec->pix_fmt));
+#else
+	printf("%s", av_get_pix_fmt_name(codec->pix_fmt));
+#endif
 	printf("\n");
       }
     }
@@ -290,6 +294,7 @@ int main(int argc, char *argv[])
   printf("  <bitrate>%d</bitrate>\n", ic->bit_rate);
   printf("  <size>%lld</size>\n", ic->file_size);
   printf("  <startoffset>%lld</startoffset>\n", ic->start_time);
+#if LIBAVFORMAT_BUILD < 3473920
   if (ic->title) printf("  <title>%s</title>\n", ic->title);
 
   if (ic->copyright) printf("  <copyright>%s</copyright>\n", ic->copyright);
@@ -300,6 +305,12 @@ int main(int argc, char *argv[])
   if (ic->year) printf("  <year>%d</year>\n", ic->year);
   if (ic->track) printf("  <track>%d</track>\n", ic->track);
   if (ic->genre) printf("  <genre>%s</genre>\n", ic->genre);
+#else
+  AVMetadataTag *next = NULL;
+  while((next=av_metadata_get(ic->metadata, "", next, AV_METADATA_IGNORE_SUFFIX))) {
+    printf("  <%s>%s</%s>\n", next->key, next->value ,next->key);
+  }
+#endif
 
 #if LIBAVFORMAT_BUILD > 4629
   printf("  <muxrate>%d</muxrate>\n", ic->mux_rate);
@@ -363,7 +374,11 @@ int main(int argc, char *argv[])
 #else
       printf("    <framerate>%.2f</framerate>\n", av_q2d(st->r_frame_rate));
 #endif
+#if LIBAVFORMAT_BUILD < 3473920
       printf("    <pixelformat>%s</pixelformat>\n", avcodec_get_pix_fmt_name(codec->pix_fmt));
+#else
+      printf("    <pixelformat>%s</pixelformat>\n", av_get_pix_fmt_name(codec->pix_fmt));
+#endif
     }
 
     if (codec->channels) 
