@@ -90,9 +90,9 @@ int64_t file_frame_offset = 0;
 /* Option flags and variables */
 char	*current_file = NULL;
 char    *smpte_offset = NULL;
-long	ts_offset = 0;
-long	userFrame = 0; // seek to this frame if jack and midi are N/A
-long	dispFrame = 0; // global strorage... = (SMPTE+offset) with boundaries to [0..movie_file_frames]
+long 	ts_offset = 0;
+long 	userFrame = 0; // seek to this frame if jack and midi are N/A
+long 	dispFrame = 0; // global strorage... = (SMPTE+offset) with boundaries to [0..movie_file_frames]
 int 	force_redraw = 0;
 
 int 	interaction_override = 0; // disable some options.
@@ -130,7 +130,7 @@ int remote_mode =0;	/* 0: undirectional ; >0: bidir
 int try_codec =0;	/* --try-codec */
 
 #ifdef HAVE_MIDI
-char midiid[128] = "-2";/* --midi # -1: autodetect -2: jack*/
+char midiid[128] = "-2";/* --midi # -1: autodetect -2: jack-transport, -3: none/userFrame */
 int midi_clkconvert =0;	/* --midifps [0:MTC|1:VIDEO|2:RESAMPLE] */
 char *midi_driver = NULL; /* --mididriver */
 #endif
@@ -139,6 +139,20 @@ int have_dropframes =0; /* detected from MTC;  TODO: force to zero if jack or us
 int jack_clkconvert =1; /* --jackfps  - NOT YET IMPLEMENTED
                           [0:audio_frames_per_video_frame
                            1:video-file] */
+int use_jack = 1;
+#ifdef HAVE_LTCSMPTE
+int use_ltc = 0;        /* -l , --ltc */
+#endif 
+char *load_rc = NULL;
+char *load_movie = NULL;
+#ifdef JACK_SESSION
+char *jack_uuid = NULL;
+int jack_session_restore = 0;
+int js_winx = -1;
+int js_winy = -1;
+int js_winw = -1;
+int js_winh = -1;
+#endif 
 
 #ifdef HAVE_LASH
 lash_client_t *lash_client;
@@ -206,7 +220,7 @@ static struct option const long_options[] =
   {"info", no_argument, 0, 'i'},
   {"ontop", no_argument, 0, 'a'},
   {"fullscreen", no_argument, 0, 's'},
-  {"nolash", no_argument, 0, 'L'},
+  {"nolash", required_argument, 0, 'L'},
   {"dropframes", no_argument, 0, 'N'},
   {"nodropframes", no_argument, 0, 'n'},
   {"letterbox", no_argument, 0, 'b'},
@@ -217,6 +231,13 @@ static struct option const long_options[] =
   {"midiclk", no_argument, 0, 'C'},
   {"no-midiclk", no_argument, 0, 'c'},
 #endif
+#ifdef HAVE_LTCSMPTE
+  {"ltc", no_argument, 0, 'l'},
+#endif
+#ifdef JACK_SESSION
+  {"uuid", required_argument, 0, 'U'},
+  {"rc", required_argument, 0, 'r'},
+#endif
 #ifdef HAVE_LIBLO
   {"osc", required_argument, 0, 'O'},
 #endif
@@ -260,6 +281,13 @@ decode_switches (int argc, char **argv)
 			   "d:"	/* midi driver */
 			   "C"	/* --midiclk */
 			   "c"	/* --no-midiclk */
+#endif
+#ifdef HAVE_LTCSMPTE
+			   "l"	/* --ltc */
+#endif
+#ifdef JACK_SESSION
+			   "r:"	/* --rc */
+			   "U:"	/* --uuid */
 #endif
 			   "N"	/* --dropframes */
 			   "n"	/* --nodropframes */
@@ -386,6 +414,21 @@ decode_switches (int argc, char **argv)
           midi_clkadj = 0;
 	  break;
 #endif
+#ifdef HAVE_LTCSMPTE
+	case 'l':		/* --ltc */
+          use_ltc = 1;
+	  break;
+#endif
+	case 'U':		/* --uuid */
+#ifdef JACK_SESSION
+          if (jack_uuid) free(jack_uuid);
+          jack_uuid = strdup(optarg);
+#endif
+	  break;
+	case 'r':		/* --rc */
+          if (load_rc) free(load_rc);
+          load_rc = strdup(optarg);
+	  break;
 	case 'V':
 	  printversion();
 	  exit(0);
@@ -417,20 +460,25 @@ jack video monitor\n", program_name);
 "  -V, --version             print version information and exit\n"
 "  -q, --quiet, --silent     inhibit usual output\n"
 "  -v, --verbose             print more information\n"
-"  -A, --avverbose           dump ffmpeg messages.\n"
-"  -S, --nosplash            do not display splash image on startup.\n"
 "\n"
-"  -s, --fullscreen          start xjadeo in fullscreen mode.\n"
-  "                            requires x11 or xv videomode.\n"
+"  -A, --avverbose           dump ffmpeg messages.\n"
 "  -a, --ontop               stack xjadeo window on top of the desktop.\n"
 "                            requires x11 or xv videomode and EWMH.\n"
 "  -b, --letterbox           retain apect ratio when scaling (Xv only).\n"
 #ifdef HAVE_MIDI
 "  -c, --no-midiclk          ignore MTC quarter frames.\n"
 #endif
+#ifdef HAVE_MIDI
+"  -d <name>,                specify midi-driver to use. run 'xjadeo -V' to\n"
+"     --midi-driver <name>   list supported driver(s). <name> is not case-\n"
+"                            sensitive and can be shortened to the first unique\n"
+"                            name. eg '-d j' for jack, '-d alsa-r' for alsa-raw\n"
+#endif
 "  -f <val>, --fps <val>     display update freq. - default -1 use file's fps\n"
-"  -i <int> --info <int>     render OnScreenDisplay info: 0:off, %i:frame,\n"
+"  -i <int>, --info <int>    render OnScreenDisplay info: 0:off, %i:frame,\n"
 "                            %i:smpte, %i:both. (use remote ctrl for more opts.)\n"
+"",	OSD_FRAME,OSD_SMPTE,OSD_FRAME|OSD_SMPTE); // :)
+  printf ("" /* take a breath */
 "  -I, --ignorefileoffset    set the beginning of the file to SMPTE zero.\n"
 "                            eg. override timestamps of split vob files.\n"
 "  -k, --keyframes           seek to keyframes only\n"
@@ -441,13 +489,13 @@ jack video monitor\n", program_name);
 "  --lash-no-autoresume      [liblash option]\n"
 "  --lash-no-start-server    [liblash option]\n"
 #endif /* HAVE_LASH */
-"",	OSD_FRAME,OSD_SMPTE,OSD_FRAME|OSD_SMPTE); // :)
-  printf ("" /* take a breath */
+#ifdef HAVE_LTCSMPTE
+"  -l, --ltc                 sync to LinearTimeCode (audio-jack).\n"
+#endif
+#ifdef JACK_SESSION
+"  -U, --uuid                specify JACK-SESSION UUID.\n"
+#endif
 #ifdef HAVE_MIDI
-"  -d <name>,                specify midi-driver to use. run 'xjadeo -V' to\n"
-"     --midi-driver <name>   list supported driver(s). <name> is not case-\n"
-"                            sensitive and can be shortened to the first unique\n"
-"                            name. eg '-d j' for jack, '-d alsa-r' for alsa-raw\n"
 "  -m <port>,                use MTC instead of jack-transport\n"
 "      --midi <port>         <port> argument is driver-specific:\n"
 "                            * jack-midi: specify midi-port name to connect to\n"
@@ -464,7 +512,7 @@ jack video monitor\n", program_name);
 "                            2: use video file FPS\n" 
 "                            3: \"resample\": videoFPS / MTC \n" 
 #endif /* HAVE_MIDI */
-/*
+/* - undocumented /hidden/ options
 "  -n , --nodropframes       parse MTC as announced, but do not use frame-drop\n" 
 "                            algorithm for OSD - useful for debugging\n"
 "  -N , --dropframes         force the SMPTE converter to use the drop-frames\n" 
@@ -476,19 +524,24 @@ jack video monitor\n", program_name);
 "                            unless you really know what you are doing.\n" 
 */
 "  -o <int>, --offset <int>  add/subtract <int> video-frames to/from timecode\n"
-"  -P , --genpts             ffmpeg option - ignore timestamps in the file.\n"
-#ifdef HAVE_MQ
-"  -Q, --mq                  set-up RT message queues for xjremote\n"
-#elif defined HAVE_IPCMSG
-"  -W, --ipc                 set-up IPC message queues for xjremote\n"
-#endif
 #ifdef HAVE_LIBLO
 "  -O <port>, --osc <port>   listen for OSC messages on given port.\n"
 #endif
+"  -P , --genpts             ffmpeg option - ignore timestamps in the file.\n"
+#ifdef HAVE_MQ
+"  -Q, --mq                  set-up RT message queues for xjremote\n"
+#endif
+"  -r <file>, --rc <file>    .rc settings file to load.\n"
 "  -R, --remote              remote control (stdin) - implies non verbose&quiet\n"
+"  -S, --nosplash            do not display splash image on startup.\n"
+"  -s, --fullscreen          start xjadeo in fullscreen mode.\n"
+"                            requires x11 or xv videomode.\n"
 "  -t, --try-codec           checks if the video-file can be played by jadeo.\n"
 "                            exits with code 1 if the file is not supported.\n"
 "			     no window is opened in this mode.\n"
+#ifdef HAVE_IPCMSG
+"  -W, --ipc                 set-up IPC message queues for xjremote\n"
+#endif
 "  -x <int>, --vo <int>,     set the video output mode (default: 0 - autodetect\n"
 "      --videomode <int>     -1 prints a list of available modes.\n"
 "  \n"
@@ -499,20 +552,29 @@ jack video monitor\n", program_name);
 
 static void printversion (void) {
   printf ("xjadeo ");
+  printf ("version %s ", VERSION);
 #ifdef SUBVERSION
-  printf ("version %s svn-%s [ ", VERSION, SUBVERSION);
-#else
-  printf ("version %s [ ", VERSION);
+  if (strlen(SUBVERSION)>0 && strcmp(SUBVERSION, "exported")) {
+    printf ("scm-%s ", SUBVERSION);
+  }
 #endif
+  printf ("[ ");
 #ifdef HAVE_LASH
   printf("LASH ");
 #endif 
+#ifdef HAVE_LTCSMPTE
+  printf("LTC ");
+#endif
+#ifdef JACK_SESSION
+  printf("JACK-SESSION ");
+#endif
 #ifdef HAVE_MQ
   printf("POSIX-MQueue ");
 #elif defined HAVE_IPCMSG
   printf("IPC-MSG ");
 #endif
-  printf("]\n compiled with LIBAVFORMAT_BUILD 0x%x = %i\n", LIBAVFORMAT_BUILD, LIBAVFORMAT_BUILD);
+  printf("]\n compiled with ffmpeg: AVFORMAT=0x%x AVCODEC=0x%x\n", 
+      LIBAVFORMAT_BUILD, LIBAVCODEC_BUILD);
   printf(" MTC-MIDI: ");
 #ifndef HAVE_MIDI
   printf("disabled.");
@@ -539,7 +601,7 @@ static void printversion (void) {
 #if HAVE_LIBXV
 		"Xv "
 #endif 
-#if HAVE_SDL
+#ifdef HAVE_SDL
 		"SDL "
 #endif 
 #if HAVE_IMLIB
@@ -600,10 +662,16 @@ void clean_up (int status) {
   if (midi_driver) free(midi_driver);
   if (midi_connected()) midi_close(); 
   else
+#endif
+#ifdef HAVE_LTCSMPTE
+  if (ltcjack_connected()) close_ltcjack(); 
+  else
 #endif
   close_jack();
 
   if (smpte_offset) free(smpte_offset);
+  if (load_rc) free(load_rc);
+  if (load_movie) free(load_movie);
   
   if (!want_quiet)
     fprintf(stdout, "\nBye!\n");
@@ -611,10 +679,12 @@ void clean_up (int status) {
 }
 
 void catchsig (int sig) {
+#ifndef HAVE_WINDOWS
   signal(SIGHUP, catchsig); /* reset signal */
   signal(SIGINT, catchsig);
 //signal(SIGHUP, SIG_IGN); /* reset signal */
 //signal(SIGINT, SIG_IGN);
+#endif
   if (!want_quiet)
     fprintf(stdout,"\n CAUGHT SIGINT - shutting down.\n");
   loop_flag=0;
@@ -673,13 +743,18 @@ main (int argc, char **argv)
   if (videomode < 0) vidoutmode(videomode); // dump modes and exit.
 
   if ((i+1)== argc) movie = argv[i];
-  else if ((remote_en || mq_en || ipc_queue) && i==argc) movie = "";
+  else if ((remote_en || mq_en || ipc_queue || load_rc) && i==argc) movie = "";
 #ifndef HAVE_MACOSX
   else usage (EXIT_FAILURE);
 #else
   else movie = "";
 #endif
 
+  if (load_rc) {
+    if (testfile(load_rc)) readconfig(load_rc);
+    if (load_movie) movie = load_movie;
+  }
+
   if (want_verbose) printf ("xjadeo %s\n", VERSION);
 
   if (lashed==1 && remote_en) {
@@ -697,9 +772,10 @@ main (int argc, char **argv)
 
   // only try to seek to frame 1 and decode it.
   if (try_codec) do_try_this_file_and_exit (movie);
-
+#ifndef HAVE_WINDOWS
   signal (SIGHUP, catchsig);
   signal (SIGINT, catchsig);
+#endif
 
   if (osc_port > 0) initialize_osc(osc_port);
 
@@ -724,7 +800,15 @@ main (int argc, char **argv)
   if (getvidmode() ==0) {
 	fprintf(stderr,"Could not open display.\n");
   	if(!remote_en) {  // && !mq_en && !ipc_queue) { /* TODO: allow windowless startup with MQ ?! */
-		// TODO: cleanup close midi and file ??
+#ifdef HAVE_MIDI
+                if (midi_driver) free(midi_driver);
+                if (midi_connected()) midi_close(); 
+                else
+#endif
+#ifdef HAVE_LTCSMPTE
+                if (ltcjack_connected()) close_ltcjack(); 
+                else
+#endif
 		close_jack();
 		exit(1);
 	}
@@ -734,16 +818,30 @@ main (int argc, char **argv)
 
 #ifdef HAVE_MIDI
   midi_choose_driver(midi_driver);
+
+#ifdef JACK_SESSION
+  if (jack_uuid && !strcmp(midi_driver_name(), "JACK-MIDI")) {
+    // don't auto-connect jack-midi on session restore.
+    if (atoi(midiid) == 0) midiid[0]='\0';
+  }
+#endif
+
   if (atoi(midiid) >= -1 ) {
     if (!want_quiet) 
       printf("using MTC as sync-source.\n");
     midi_open(midiid);
   } else 
+#endif
+#ifdef HAVE_LTCSMPTE
+  if (use_ltc) {
+    open_ltcjack(NULL);
+  } else
 #endif
   {
     if (!want_quiet) 
       printf("using JACK-transport as sync source.\n");
-    open_jack();
+    if (use_jack)
+      open_jack();
   }
 
 #ifdef HAVE_MQ
@@ -753,7 +851,7 @@ main (int argc, char **argv)
 #endif
   if(remote_en) open_remote_ctrl();
 
-  display_frame(0LL,1);
+  display_frame(0LL,1,1);
   splash(buffer); 
 
   event_loop();
