@@ -43,7 +43,6 @@
  *       which is currenlty 199.
  *
  */
-
 #include "xjadeo.h"
 
 #ifdef OLD_FFMPEG
@@ -130,8 +129,8 @@ extern char jackid[16];
 
 
 // TODO: someday we can implement 'mkfifo' or open / pipe
-#define REMOTE_RX fileno(stdin) 
-#define REMOTE_TX fileno(stdout)
+#define REMOTE_RX (fileno(stdin))
+#define REMOTE_TX (fileno(stdout))
 
 #define REMOTEBUFSIZ 4096
 int remote_read(void);
@@ -519,10 +518,47 @@ void xapi_jack_status(void *d) {
 		remote_printf(220,"jackclient=%s",jackid);
 	else 
 		remote_printf(100,"not connected to jack server");
+}
 
+void xapi_ltc_status(void *d) {
+	if (ltcjack_connected())
+		remote_printf(220,"jackclient=%s",ltc_jack_client_name());
+	else 
+		remote_printf(100,"no open LTC JACK source");
+}
+
+void xapi_open_ltc(void *d) {
+#ifdef HAVE_LTCSMPTE
+#ifdef HAVE_MIDI
+	midi_close();
+#endif
+	close_jack();
+	open_ltcjack((char *) d); // TODO: autoconnect 
+	if (ltcjack_connected())
+		remote_printf(100,"opened LTC jack port.");
+	else 
+		remote_printf(405,"failed to connect to jack server");
+#else
+	remote_printf(499,"LTC-jack is not available.");
+#endif
+}
+
+void xapi_close_ltc(void *d) {
+#ifdef HAVE_LTCSMPTE
+	close_ltcjack();
+	remote_printf(100,"closed ltc-jack connection");
+#else
+	remote_printf(499,"LTC-jack is not available.");
+#endif
 }
 
 void xapi_open_jack(void *d) {
+#ifdef HAVE_MIDI
+	midi_close();
+#endif
+#ifdef HAVE_LTCSMPTE
+	close_ltcjack();
+#endif
 	open_jack();
 	if (jack_client) 
 		remote_printf(100,"connected to jack server.");
@@ -582,7 +618,8 @@ void xapi_osd_on(void *d) {
 
 void xapi_osd_text(void *d) {
 	snprintf(OSD_text,128,"%s",(char*)d);
-	display_frame((int64_t)(dispFrame),1); // update OSD
+	force_redraw=1;
+	//display_frame((int64_t)(dispFrame),1,1); // update OSD
 	xapi_osd_on(NULL);
 }
 
@@ -635,6 +672,10 @@ void xapi_posd(void *d) {
 
 void xapi_psync(void *d) {
 	int ss =0;
+#ifdef HAVE_LTCSMPTE
+	if (ltcjack_connected()) ss=3;
+	else
+#endif
 #ifdef HAVE_MIDI
 	if (midi_connected()) ss=2;
 	else
@@ -850,6 +891,13 @@ Dcommand cmd_jack[] = {
 	{NULL, NULL, NULL , NULL, 0}
 };
 
+Dcommand cmd_ltc[] = {
+	{"connect", ": connect and sync to jack server", NULL, xapi_open_ltc , 0 },
+	{"disconnect", ": disconnect from jack server", NULL, xapi_close_ltc , 0 },
+	{"status", ": get status of jack connection", NULL, xapi_ltc_status , 0 },
+	{NULL, NULL, NULL , NULL, 0}
+};
+
 Dcommand cmd_osd[] = {
 	{"frame " , "<ypos>: render current framenumber. y=0..100 (<0 disable)", NULL, xapi_osd_frame, 0 },
 	{"smpte " , "<ypos>: render smpte. y=0..100 (<0 disable)", NULL, xapi_osd_smpte, 0 },
@@ -926,11 +974,11 @@ Dcommand cmd_window[] = {
 
 Dcommand cmd_set[] = {
 	{"fps ", "<float>: set current update frequency", NULL, xapi_sfps , 0 },
-	{"offset", "<int>: set current frame offset", NULL, xapi_soffset , 0 },
+	{"offset ", "<int>: set current frame offset", NULL, xapi_soffset , 0 },
 	{"timescale ", "<float> <int>: set timescale and offset", NULL, xapi_stimescale , 0 },
 	{"loop ", "<int>: 0: normal, 1:wrap around", NULL, xapi_sloop , 0 },
 	{"seekmode ", "<1-3>: seek continuous, to any or to keyframes only", NULL, xapi_sseekmode, 0 },
-	{"framerate ", "<float>: show frame rate of video file", NULL, xapi_sframerate , 0 },
+	{"framerate ", "<float>: override frame rate of video file", NULL, xapi_sframerate , 0 },
 	{"override ", "<int>: disable window events", NULL, xapi_soverride , 0 },
 	{NULL, NULL, NULL , NULL, 0}
 };
@@ -947,8 +995,9 @@ Dcommand cmd_root[] = {
 	{"get", " .. : query xjadeo variables or state", cmd_get, NULL, 0 },
 	{"set", " .. : set xjadeo variables", cmd_set, NULL, 0 },
 	{"osd", " .. : on screen display commands", cmd_osd, NULL, 0 },
-	{"jack", " .. : jack commands", cmd_jack, NULL, 0 },
-	{"midi", " .. : midi commands", cmd_midi, NULL, 0 },
+	{"jack", " .. : jack sync commands", cmd_jack, NULL, 0 },
+	{"midi", " .. : midi sync commands", cmd_midi, NULL, 0 },
+	{"ltc", " ..  : LTC sync commands", cmd_ltc, NULL, 0 },
 	{"reverse", ": set timescale to reverse playback from now", NULL , xapi_sreverse, 0 },
 
 	{"list videomodes" , ": displays a list of possible video modes", NULL, xapi_lvideomodes, 0 },
@@ -1002,9 +1051,11 @@ void exec_remote_cmd_recursive (Dcommand *leave, char *cmd) {
 	}
 	if (leave[i].children) 
 		exec_remote_cmd_recursive(leave[i].children,cmd+strlen(leave[i].name));
-	else if (leave[i].func) 
-		leave[i].func(cmd+strlen(leave[i].name));
-	else 
+	else if (leave[i].func) {
+		char *arg= cmd+strlen(leave[i].name);
+		strtok(arg, "\r\n");
+		leave[i].func(arg);
+	} else 
 		remote_printf(401,"command not implemented.");
 }
 
@@ -1032,7 +1083,6 @@ typedef struct {
 }remotebuffer;
 
 remotebuffer *inbuf;
-
 int remote_read_io(void) {
 	int rx;
 	char *start, *end;
@@ -1045,15 +1095,43 @@ int remote_read_io(void) {
 
 	while ((end = strchr(start, '\n'))) {
 		*(end) = '\0';
-		//exec_remote_cmd(start);
-		exec_remote_cmd_recursive(cmd_root,start);
+		//if (strlen(start) > 0) 
+			exec_remote_cmd_recursive(cmd_root,start);
 		inbuf->offset-=((++end)-start);
 		if (inbuf->offset) memmove(inbuf->buf,end,inbuf->offset);
 	}
 
-	return(0);
+	return(rx>0?0:-1);
 }
 
+#ifdef HAVE_WINDOWS
+int remote_read_h(void) {
+	int rv=-1;
+	char buf[BUFSIZ];
+	DWORD bytesAvail = 0;
+	HANDLE h = GetStdHandle(STD_INPUT_HANDLE);
+	do {
+		PeekNamedPipe(h, 0, 0, 0, &bytesAvail, 0);
+		DWORD sr=0;
+		if (bytesAvail > 0 && ReadFile(h, buf, BUFSIZ, &sr, NULL) && sr>0) {
+			buf[sr]=0;
+			char *start, *end;
+			start = buf;
+			while (*start && (end = strchr(start, '\n'))) {
+				*(end) = '\0';
+				strtok(start, "\r");
+				//if (strlen(start) > 0) 
+					exec_remote_cmd_recursive(cmd_root,start);
+				start=end+1;
+			}
+		  rv=0;
+		}
+	} while (bytesAvail>0);
+	return rv;
+}
+#endif
+
+
 #ifdef HAVE_MQ
 # define LOGLEN MQLEN
 #elif defined(HAVE_IPCMSG)
@@ -1092,6 +1170,7 @@ int remote_fd_set(fd_set *fd) {
 	return( REMOTE_RX+1);
 }
 
+
 //--------------------------------------------
 // POSIX message queeue
 //--------------------------------------------
@@ -1125,6 +1204,7 @@ int remote_read_mq(void) {
 
 	while ((rx=mymq_read(data)) > 0 ) { 
 		if ((t =  strchr(data, '\n'))) *t='\0';
+		//if (strlen(data) < 1) continue;
 		exec_remote_cmd_recursive(cmd_root,data);
 		rv=0;
 	}
@@ -1164,7 +1244,7 @@ int myipc_reply(int id, char *msg){
 	struct msgbuf1 txbuf;
 	txbuf.mtype=1;
   snprintf(txbuf.mtext, BUFSIZ, "@%i %s\n", id, msg); // XXX
-  if (msgsnd(msqtx, (const void*) &txbuf, strlen(txbuf.mtext), 0) == -1) {
+  if (msgsnd(msqtx, (const void*) &txbuf, strlen(txbuf.mtext), IPC_NOWAIT) == -1) {
 		fprintf(stderr, "msgsnd failed., Error = %d: %s\n", errno, strerror(errno));
 		return -1;
 	}
@@ -1187,10 +1267,15 @@ int remote_read_ipc () {
 		return (-1);
 	}
 
-	// TODO WHILE  LOOP..
-	char *t;
-	if ((t = strchr(rxbuf.mtext, '\n'))) *t='\0';
-	exec_remote_cmd_recursive(cmd_root,rxbuf.mtext);
+	char *t, *s;
+	s=rxbuf.mtext; // TODO remember end of long messages..
+	while (s && *s && (t = strchr(s, '\n'))) {
+		*t='\0';
+	  if (strlen(s) < 1) continue;
+	  exec_remote_cmd_recursive(cmd_root,s);
+		s=t+1;
+	}
+	remote_read_ipc(); // read all queued messages..
 	return(0);
 }
 
