@@ -54,6 +54,14 @@
 #include <sys/time.h>
 #include <unistd.h>
 
+/* ffmpeg backwards compat */
+
+#ifndef HAVE_WINDOWS /* XXX temp workaround - win32 older ffmpeg */
+#ifndef CODEC_TYPE_VIDEO
+#define CODEC_TYPE_VIDEO AVMEDIA_TYPE_VIDEO
+#endif
+#endif
+
 //------------------------------------------------
 // extern Globals (main.c)
 //------------------------------------------------
@@ -92,6 +100,7 @@ extern int	want_quiet;
 extern int	want_debug;
 extern int	want_verbose;
 extern int	want_avverbose;
+extern int	want_nosplash;
 extern int	want_genpts;
 extern int	want_ignstart;
 extern int	remote_en;
@@ -100,6 +109,9 @@ extern int	mq_en;
 extern char	*ipc_queue;
 extern double	delay;
 extern int	seekflags;
+#ifdef HAVE_LTCSMPTE
+extern int  use_ltc;
+#endif
 
 #ifdef TIMEMAP
 long		timeoffset = 0;
@@ -115,11 +127,30 @@ extern int	OSD_mode;
 const AVRational c1_Q = { 1, 1 };
 double 		tpf = 1.0; /* pts/dts increments per video-frame - cached value */
 
+#ifdef JACK_SESSION
+extern int jack_session_restore;
+extern int js_winx;
+extern int js_winy;
+extern int js_winw;
+extern int js_winh;
+#endif
+
+void js_apply() {
+#ifdef JACK_SESSION
+	if (jack_session_restore) {
+		jack_session_restore = 0;
+		if (js_winx > 0 && js_winy > 0)
+			Xposition(js_winx, js_winy);
+		if (js_winw > 0 && js_winh > 0)
+			Xresize(js_winw,js_winh);
+	}
+#endif
+}
 //--------------------------------------------
 // main event loop
 //--------------------------------------------
 //
-void select_sleep (int usec) {
+int select_sleep (int usec) {
 	int remote_activity = 0;
 	fd_set fd;
 	int max_fd=0;
@@ -142,7 +173,22 @@ void select_sleep (int usec) {
 	if (remote_activity) {
 	  tv.tv_sec = 0; tv.tv_usec = 1;
 	}
-	if (select(max_fd, &fd, NULL, NULL, &tv)) remote_read_io();
+#if 0 /* pselect sleep */
+	struct timespec	ts;
+	ts.tv_sec = (usec / 1000000L);
+	ts.tv_nsec = (usec % 1000000L)*1000;
+	if (pselect(max_fd, &fd, NULL, NULL, &ts,NULL)) remote_read_io();
+#elif defined HAVE_WINDOWS
+	if (!remote_en || remote_read_h()) {
+		Sleep((usec+ 999) /1000);
+	}
+#else
+	if (select(max_fd, &fd, NULL, NULL, &tv)) {
+		remote_read_io();
+		return 1;
+	}
+#endif
+	return remote_activity;
 }
 
 void event_loop(void) {
@@ -150,7 +196,6 @@ void event_loop(void) {
 	struct timeval	clock1, clock2;
 	long		newFrame, offFrame;
 	long		nanos;
-	struct timespec	ts;
 	double 		dly;
 	static int	splashed = -1;
 
@@ -166,6 +211,7 @@ void event_loop(void) {
 			select_sleep(2e5L);
 			handle_X_events();
 			lash_process();
+			js_apply();
 			continue;
 		}
     
@@ -173,10 +219,25 @@ void event_loop(void) {
 		if (midi_connected()) newFrame = midi_poll_frame();
 		else
 #endif
+#ifdef HAVE_LTCSMPTE
+		if (ltcjack_connected()) newFrame = ltc_poll_frame();
+		else
+#endif
+
 		newFrame = jack_poll_frame();
 
 		if (newFrame <0 ) newFrame=userFrame;
 
+#if 0 // DEBUG
+		static long		oldFrame = 0;
+		if (oldFrame != newFrame) {
+			if (oldFrame +1 != newFrame) {
+				printf("\ndiscontinuity %li -> %li\n", oldFrame, newFrame);
+			}
+			oldFrame=newFrame;
+		}
+#endif
+
 #ifdef TIMEMAP
 		newFrame = (long) floor((double) newFrame * timescale) + timeoffset;
 		// TODO: calc newFrames/frames instead of while-loop
@@ -188,7 +249,7 @@ void event_loop(void) {
 
 		offFrame = newFrame + ts_offset;
 		long curFrame = dispFrame;
-		display_frame((int64_t)(offFrame), force_redraw);
+		display_frame((int64_t)(offFrame), force_redraw, !splashed || want_nosplash);
 
 		if ((remote_en||mq_en||ipc_queue) && ((remote_mode&1) || ((remote_mode&2)&& curFrame!=dispFrame)) ) {
 		/*call 	xapi_pposition ?? -> rv:200
@@ -202,10 +263,9 @@ void event_loop(void) {
 
 		if (splashed) {
 			if (splashed == -1) {
-				splashed =  5.5/dly;	
-				splash(buffer);
+				splashed =  4.5/dly;	
 			}
-			if(!--splashed) force_redraw=1;
+			splash(buffer);
 		}
 
 		if(want_verbose) {
@@ -221,14 +281,17 @@ void event_loop(void) {
 
 		handle_X_events();
 		lash_process();
+		js_apply();
     
 		gettimeofday(&clock2, NULL);
 		elapsed_time = ((double) (clock2.tv_sec-clock1.tv_sec)) + ((double) (clock2.tv_usec-clock1.tv_usec)) / 1000000.0;
 		if(elapsed_time < dly) {
 			nanos = (long) floor(1e9L * (dly - elapsed_time));
-			ts.tv_sec = (nanos / 1000000000L);
-			ts.tv_nsec = (nanos % 1000000000L);
-			select_sleep(nanos/1000L);
+			if (!select_sleep(nanos/1000L)) {
+				if (splashed) {
+					if(!--splashed) force_redraw=1;
+				}
+			}
 		}
 		clock1.tv_sec=clock2.tv_sec;
 		clock1.tv_usec=clock2.tv_usec;
@@ -309,7 +372,11 @@ int open_movie(char* file_name) {
 		return (-1);
 	}
 
+#if LIBAVFORMAT_BUILD < 0x350200
 	if (!want_quiet) dump_format(pFormatCtx, 0, file_name, 0);
+#else
+	if (!want_quiet) av_dump_format(pFormatCtx, 0, file_name, 0);
+#endif
 
 	/* Find the first video stream */
 	for(i=0; i<pFormatCtx->nb_streams; i++)
@@ -699,7 +766,7 @@ read_frame:
 	return (0); // seek failed.
 }
 
-void display_frame(int64_t timestamp, int force_update) {
+void display_frame(int64_t timestamp, int force_update, int do_render) {
 	static AVPacket packet;
 	static int      fFirstTime=1;
 	int             frameFinished;
@@ -713,7 +780,8 @@ void display_frame(int64_t timestamp, int force_update) {
 		fprintf(stdout, "\t\t\t\tdisplay:%07li  \r", (long int) timestamp);
 
 	dispFrame = timestamp;
-	if (OSD_mode&OSD_FRAME) snprintf(OSD_frame,48,"Frame: %li", dispFrame);
+	if (OSD_mode&OSD_FRAME) 
+		snprintf(OSD_frame,48,"Frame: %li", dispFrame);
 	if (OSD_mode&OSD_SMPTE) frame_to_smptestring(OSD_smpte,dispFrame);
 
 	if(fFirstTime) {
@@ -759,7 +827,8 @@ void display_frame(int64_t timestamp, int force_update) {
 					(AVPicture*)pFrame, pCodecCtx->pix_fmt, pCodecCtx->width, 
 					pCodecCtx->height);
 #endif
-				render_buffer(buffer); // in pFrameFMT
+				if (do_render) 
+					render_buffer(buffer); // in pFrameFMT
 				av_free_packet(&packet); /* XXX */
 				break;
 			} else  { 
