@@ -3,13 +3,23 @@
 #include <math.h>
 #include <stdint.h> 	/* uint8_t */
 #include <string.h> 	/* memcpy */
-#include <sys/select.h> 
+#include <unistd.h>
 
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#ifdef HAVE_WINDOWS
+# include <windows.h>
+# include <winsock.h>
+
+# define vsnprintf _vsnprintf
+# define snprintf _snprintf
+#else
+# include <sys/select.h> 
+#endif
+
 #ifdef HAVE_LASH
 # include <lash/lash.h>
 #endif
@@ -112,14 +122,17 @@ void close_mq_ctrl (void) ;
 void open_mq_ctrl (void);
 void close_ipcmsg_ctrl (void) ;
 int  open_ipcmsg_ctrl (const char *);
-int remote_fd_set(fd_set *fd);
 int remote_read_mq(void);
 int remote_read_ipc(void);
 int remote_read_io(void);
+#ifdef HAVE_WINDOWS
+int remote_read_h(void);
+#endif
 void remote_printf(int val, const char *format, ...);
+int remote_fd_set(fd_set *fd);
 
 /* xjadeo.c */
-void display_frame(int64_t timestamp, int force_update);
+void display_frame(int64_t timestamp, int force_update, int do_render);
 int open_movie(char* file_name);
 int close_movie();
 void avinit (void);
@@ -134,6 +147,15 @@ void open_jack(void );
 void close_jack(void);
 int jack_connected(void);
 
+/* ltc-jack.c function prototypes */
+#ifdef HAVE_LTCSMPTE
+long ltc_poll_frame (void);
+void open_ltcjack(char *autoconnect);
+void close_ltcjack(void);
+int ltcjack_connected(void);
+const char *ltc_jack_client_name();
+#endif 
+
 /* smpte.c prototypes */
 long int smptestring_to_frame (char *str);
 void frame_to_smptestring(char *smptestring, long int frame);
@@ -155,6 +177,9 @@ void shutdown_osc(void);
 
 /* configfile.c */
 void xjadeorc (void);
+int testfile (char *filename);
+int saveconfig (const char *filename);
+int readconfig (char *fn);
 
 /* freetype - On screen display */
 int render_font (char *fontfile, char *text);
